@@ -7,7 +7,7 @@ use Scalar::Util qw( looks_like_number weaken );
 use List::Util qw( all any );
 use Moo;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my %children_of = (
     # regions of subregions
@@ -151,10 +151,13 @@ has _countries => (
 sub BUILDARGS {
     my ($class, @args) = @_;
 
+    # constructor arguments passed as hashref
+    return $args[0]
+        if @args == 1
+        && ref $args[0] eq 'HASH';
+
     # the `include` key is optional for the first argument
-    my %args = @args == 1 && ref $args[0] eq 'HASH' ? %{$args[0]}        :
-               @args % 2                            ? (include => @args) :
-                                                      @args              ;
+    my %args = @args % 2 ? (include => @args) : @args;
 
     if (exists $args{region}) {
         carp 'Argument "region" is deprecated; use "include" instead';
@@ -191,7 +194,7 @@ Geo::Region - Geographical regions and groupings using UN M.49 and CLDR data
 
 =head1 VERSION
 
-This document describes Geo::Region v0.06, built with Unicode CLDR v26.
+This document describes Geo::Region v0.07, built with Unicode CLDR v27.
 
 =head1 SYNOPSIS
 
@@ -216,8 +219,8 @@ This document describes Geo::Region v0.06, built with Unicode CLDR v26.
 
 This class is used to create geographical regions and groupings of subregions
 and countries. Default regional groupings are provided using the L<Unicode CLDR
-v26 Territory
-Containment|http://unicode.org/cldr/charts/26/supplemental/territory_containment_un_m_49.html>
+v27 Territory
+Containment|http://unicode.org/cldr/charts/27/supplemental/territory_containment_un_m_49.html>
 data, which is an extension of the United Nations L<UN
 M.49 (Rev.3)|http://unstats.un.org/unsd/methods/m49/m49regin.htm> standard.
 
@@ -304,17 +307,17 @@ by the Geo::Region instance.
 
 =over
 
-=item L<Geo::Region::Constant> — Constants for UN M.49 and CLDR region codes
+=item * L<Geo::Region::Constant> — Constants for UN M.49 and CLDR region codes
 
-=item L<Unicode CLDR: UN M.49 Territory
-Containment|http://unicode.org/cldr/charts/26/supplemental/territory_containment_un_m_49.html>
+=item * L<Unicode CLDR: UN M.49 Territory
+Containment|http://unicode.org/cldr/charts/27/supplemental/territory_containment_un_m_49.html>
 
-=item L<United Nations: UN M.49 Standard Country, Area, & Region
+=item * L<United Nations: UN M.49 Standard Country, Area, & Region
 Codes|http://unstats.un.org/unsd/methods/m49/m49regin.htm>
 
-=item L<Locale::CLDR: Territory Containment|Locale::CLDR/Territory-Containment>
+=item * L<Locale::CLDR: Territory Containment|Locale::CLDR/Territory-Containment>
 
-=item L<Geo::Region|https://github.com/patch/geo-region-pm6> for Perl 6
+=item * L<Geo::Region|https://github.com/patch/geo-region-pm6> for Perl 6
 
 =back
 
@@ -329,7 +332,7 @@ L<code.shutterstock.com|http://code.shutterstock.com/>.
 
 =head1 COPYRIGHT AND LICENSE
 
-© 2014 Shutterstock, Inc.
+© 2014–2015 Shutterstock, Inc.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
