@@ -293,7 +293,7 @@ use constant {
     ZIMBABWE                             => 'ZW',
 };
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my @region = qw(
     AFRICA
@@ -602,7 +602,7 @@ Geo::Region::Constant - Constants for UN M.49 and CLDR region codes
 
 =head1 VERSION
 
-This document describes Geo::Region::Constant v0.06, built with Unicode CLDR v26.
+This document describes Geo::Region::Constant v0.07, built with Unicode CLDR v27.
 
 =head1 SYNOPSIS
 
@@ -923,13 +923,13 @@ The 249 officially assigned ISO 3166-1 alpha-2 codes.
 
 =over
 
-=item L<Geo::Region> — Geographical regions and groupings using UN M.49 and CLDR
+=item * L<Geo::Region> — Geographical regions and groupings using UN M.49 and CLDR
 data
 
-=item L<Unicode CLDR: UN M.49 Territory
-Containment|http://unicode.org/cldr/charts/26/supplemental/territory_containment_un_m_49.html>
+=item * L<Unicode CLDR: UN M.49 Territory
+Containment|http://unicode.org/cldr/charts/27/supplemental/territory_containment_un_m_49.html>
 
-=item L<United Nations: UN M.49 Standard Country, Area, & Region
+=item * L<United Nations: UN M.49 Standard Country, Area, & Region
 Codes|http://unstats.un.org/unsd/methods/m49/m49regin.htm>
 
 =back
@@ -945,7 +945,7 @@ L<code.shutterstock.com|http://code.shutterstock.com/>.
 
 =head1 COPYRIGHT AND LICENSE
 
-© 2014 Shutterstock, Inc.
+© 2014–2015 Shutterstock, Inc.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
